@@ -1,4 +1,4 @@
-/* SPDX-License-Identifier: MIT */
+// SPDX-License-Identifier: MIT
 
 #ifndef RGBDS_ASM_OUTPUT_HPP
 #define RGBDS_ASM_OUTPUT_HPP
@@ -6,13 +6,17 @@
 #include <memory>
 #include <stdint.h>
 #include <string>
+#include <unordered_map>
+#include <vector>
 
 #include "linkdefs.hpp"
 
 struct Expression;
 struct FileStackNode;
 
-extern std::string objectName;
+enum StateFeature { STATE_EQU, STATE_VAR, STATE_EQUS, STATE_CHAR, STATE_MACRO, NB_STATE_FEATURES };
+
+extern std::string objectFileName;
 
 void out_RegisterNode(std::shared_ptr<FileStackNode> node);
 void out_SetFileName(std::string const &name);
@@ -21,5 +25,6 @@ void out_CreateAssert(
     AssertionType type, Expression const &expr, std::string const &message, uint32_t ofs
 );
 void out_WriteObject();
+void out_WriteState(std::string name, std::vector<StateFeature> const &features);
 
 #endif // RGBDS_ASM_OUTPUT_HPP
