@@ -91,11 +91,11 @@ void sect_ByteString(std::vector<int32_t> const &string);
 void sect_WordString(std::vector<int32_t> const &string);
 void sect_LongString(std::vector<int32_t> const &string);
 void sect_Skip(uint32_t skip, bool ds);
-void sect_RelByte(Expression &expr, uint32_t pcShift);
-void sect_RelBytes(uint32_t n, std::vector<Expression> &exprs);
-void sect_RelWord(Expression &expr, uint32_t pcShift);
-void sect_RelLong(Expression &expr, uint32_t pcShift);
-void sect_PCRelByte(Expression &expr, uint32_t pcShift);
+void sect_RelByte(Expression const &expr, uint32_t pcShift);
+void sect_RelBytes(uint32_t n, std::vector<Expression> const &exprs);
+void sect_RelWord(Expression const &expr, uint32_t pcShift);
+void sect_RelLong(Expression const &expr, uint32_t pcShift);
+void sect_PCRelByte(Expression const &expr, uint32_t pcShift);
 void sect_BinaryFile(std::string const &name, int32_t startPos);
 void sect_BinaryFileSlice(std::string const &name, int32_t startPos, int32_t length);
 
