@@ -1,4 +1,4 @@
-/* SPDX-License-Identifier: MIT */
+// SPDX-License-Identifier: MIT
 
 #ifndef RGBDS_LINK_SYMBOL_HPP
 #define RGBDS_LINK_SYMBOL_HPP
@@ -7,8 +7,8 @@
 
 #include <stdint.h>
 #include <string>
-#include <variant>
 
+#include "either.hpp"
 #include "linkdefs.hpp"
 
 struct FileStackNode;
@@ -25,26 +25,25 @@ struct Symbol {
 	// Info contained in the object files
 	std::string name;
 	ExportLevel type;
-	char const *objFileName;
 	FileStackNode const *src;
 	int32_t lineNo;
-	std::variant<
+	Either<
 	    int32_t, // Constants just have a numeric value
 	    Label    // Label values refer to an offset within a specific section
 	    >
 	    data;
 
-	Label &label();
-	Label const &label() const;
+	Label &label() { return data.get<Label>(); }
+	Label const &label() const { return data.get<Label>(); }
 };
 
+void sym_ForEach(void (*callback)(Symbol &));
+
 void sym_AddSymbol(Symbol &symbol);
 
-/*
- * Finds a symbol in all the defined symbols.
- * @param name The name of the symbol to look for
- * @return A pointer to the symbol, or `nullptr` if not found.
- */
+// Finds a symbol in all the defined symbols.
 Symbol *sym_GetSymbol(std::string const &name);
 
+void sym_DumpLocalAliasedSymbols(std::string const &name);
+
 #endif // RGBDS_LINK_SYMBOL_HPP
