@@ -23,7 +23,7 @@ static_assert(UNSPECIFIED > 0xFF, "UNSPECIFIED should not be in byte range!");
 static constexpr off_t BANK_SIZE = 0x4000;
 
 // Short options
-static char const *optstring = "Ccf:hi:jk:L:l:m:n:Op:r:st:Vv";
+static char const *optstring = "Ccf:hi:jk:L:l:m:n:Oo:p:r:st:Vv";
 
 // Equivalent long options
 // Please keep in the same order as short opts.
@@ -45,6 +45,7 @@ static option const longopts[] = {
     {"mbc-type",         required_argument, nullptr, 'm'},
     {"rom-version",      required_argument, nullptr, 'n'},
     {"overwrite",        no_argument,       nullptr, 'O'},
+    {"output",           required_argument, nullptr, 'o'},
     {"pad-value",        required_argument, nullptr, 'p'},
     {"ram-size",         required_argument, nullptr, 'r'},
     {"sgb-compatible",   no_argument,       nullptr, 's'},
@@ -54,6 +55,7 @@ static option const longopts[] = {
     {nullptr,            no_argument,       nullptr, 0  }
 };
 
+// LCOV_EXCL_START
 static void printUsage() {
 	fputs(
 	    "Usage: rgbfix [-hjOsVv] [-C | -c] [-f <fix_spec>] [-i <game_id>] [-k <licensee>]\n"
@@ -65,6 +67,7 @@ static void printUsage() {
 	    "                                  to the man page for a list of values\n"
 	    "    -p, --pad-value <value>     pad to the next valid size using this value\n"
 	    "    -r, --ram-size <code>       set the cart RAM size byte to this value\n"
+	    "    -o, --output <path>         set the output file\n"
 	    "    -V, --version               print RGBFIX version and exit\n"
 	    "    -v, --validate              fix the header logo and both checksums (-f lhg)\n"
 	    "\n"
@@ -72,6 +75,7 @@ static void printUsage() {
 	    stderr
 	);
 }
+// LCOV_EXCL_STOP
 
 static uint8_t nbErrors;
 
@@ -696,10 +700,12 @@ static char const *mbcName(MbcType type) {
 	case MBC_WRONG_FEATURES:
 	case MBC_BAD_RANGE:
 	case MBC_BAD_TPP1:
+		// LCOV_EXCL_START
 		unreachable_();
 	}
 
 	unreachable_();
+	// LCOV_EXCL_STOP
 }
 
 static bool hasRAM(MbcType type) {
@@ -713,8 +719,7 @@ static bool hasRAM(MbcType type) {
 	case MBC3_TIMER_BATTERY:
 	case MBC5:
 	case MBC5_RUMBLE:
-	case MBC6:         // TODO: not sure
-	case BANDAI_TAMA5: // TODO: not sure
+	case BANDAI_TAMA5: // "Game de Hakken!! Tamagotchi - Osutchi to Mesutchi" has RAM size 0
 	case MBC_NONE:
 	case MBC_BAD:
 	case MBC_WRONG_FEATURES:
@@ -735,6 +740,7 @@ static bool hasRAM(MbcType type) {
 	case MBC5_RAM_BATTERY:
 	case MBC5_RUMBLE_RAM:
 	case MBC5_RUMBLE_RAM_BATTERY:
+	case MBC6: // "Net de Get - Minigame @ 100" has RAM size 3 (32 KiB)
 	case MBC7_SENSOR_RUMBLE_RAM_BATTERY:
 	case POCKET_CAMERA:
 	case HUC3:
@@ -761,7 +767,7 @@ static bool hasRAM(MbcType type) {
 		break;
 	}
 
-	unreachable_();
+	unreachable_(); // LCOV_EXCL_LINE
 }
 
 static uint8_t const nintendoLogo[] = {
@@ -811,8 +817,9 @@ static ssize_t readBytes(int fd, uint8_t *buf, size_t len) {
 	while (len) {
 		ssize_t ret = read(fd, buf, len);
 
-		if (ret == -1 && errno != EINTR) { // Return errors, unless we only were interrupted
-			return -1;
+		// Return errors, unless we only were interrupted
+		if (ret == -1 && errno != EINTR) {
+			return -1; // LCOV_EXCL_LINE
 		}
 		// EOF reached
 		if (ret == 0) {
@@ -838,8 +845,9 @@ static ssize_t writeBytes(int fd, uint8_t *buf, size_t len) {
 	while (len) {
 		ssize_t ret = write(fd, buf, len);
 
-		if (ret == -1 && errno != EINTR) { // Return errors, unless we only were interrupted
-			return -1;
+		// Return errors, unless we only were interrupted
+		if (ret == -1 && errno != EINTR) {
+			return -1; // LCOV_EXCL_LINE
 		}
 		// If anything was written, accumulate it, and continue
 		if (ret != -1) {
@@ -879,9 +887,9 @@ static void overwriteBytes(
 	memcpy(&rom0[startAddr], fixed, size);
 }
 
-static void processFile(int input, int output, char const *name, off_t fileSize) {
-	// Both of these should be true for seekable files, and neither otherwise
-	if (input == output) {
+static void
+    processFile(int input, int output, char const *name, off_t fileSize, bool expectFileSize) {
+	if (expectFileSize) {
 		assume(fileSize != 0);
 	} else {
 		assume(fileSize == 0);
@@ -893,8 +901,10 @@ static void processFile(int input, int output, char const *name, off_t fileSize)
 	ssize_t headerSize = (cartridgeType & 0xFF00) == TPP1 ? 0x154 : 0x150;
 
 	if (rom0Len == -1) {
+		// LCOV_EXCL_START
 		report("FATAL: Failed to read \"%s\"'s header: %s\n", name, strerror(errno));
 		return;
+		// LCOV_EXCL_STOP
 	} else if (rom0Len < headerSize) {
 		report(
 		    "FATAL: \"%s\" too short, expected at least %jd ($%jx) bytes, got only %jd\n",
@@ -1132,8 +1142,10 @@ static void processFile(int input, int output, char const *name, off_t fileSize)
 	// write the header
 	if (input == output) {
 		if (lseek(output, 0, SEEK_SET) == static_cast<off_t>(-1)) {
+			// LCOV_EXCL_START
 			report("FATAL: Failed to rewind \"%s\": %s\n", name, strerror(errno));
 			return;
+			// LCOV_EXCL_STOP
 		}
 		// If modifying the file in-place, we only need to edit the header
 		// However, padding may have modified ROM0 (added padding), so don't in that case
@@ -1144,9 +1156,12 @@ static void processFile(int input, int output, char const *name, off_t fileSize)
 	writeLen = writeBytes(output, rom0, rom0Len);
 
 	if (writeLen == -1) {
+		// LCOV_EXCL_START
 		report("FATAL: Failed to write \"%s\"'s ROM0: %s\n", name, strerror(errno));
 		return;
+		// LCOV_EXCL_STOP
 	} else if (writeLen < rom0Len) {
+		// LCOV_EXCL_START
 		report(
 		    "FATAL: Could only write %jd of \"%s\"'s %jd ROM0 bytes\n",
 		    static_cast<intmax_t>(writeLen),
@@ -1154,6 +1169,7 @@ static void processFile(int input, int output, char const *name, off_t fileSize)
 		    static_cast<intmax_t>(rom0Len)
 		);
 		return;
+		// LCOV_EXCL_STOP
 	}
 
 	// Output ROMX if it was buffered
@@ -1162,9 +1178,12 @@ static void processFile(int input, int output, char const *name, off_t fileSize)
 		// so it's fine to cast to `size_t`
 		writeLen = writeBytes(output, romx.data(), totalRomxLen);
 		if (writeLen == -1) {
+			// LCOV_EXCL_START
 			report("FATAL: Failed to write \"%s\"'s ROMX: %s\n", name, strerror(errno));
 			return;
+			// LCOV_EXCL_STOP
 		} else if (static_cast<size_t>(writeLen) < totalRomxLen) {
+			// LCOV_EXCL_START
 			report(
 			    "FATAL: Could only write %jd of \"%s\"'s %zu ROMX bytes\n",
 			    static_cast<intmax_t>(writeLen),
@@ -1172,6 +1191,7 @@ static void processFile(int input, int output, char const *name, off_t fileSize)
 			    totalRomxLen
 			);
 			return;
+			// LCOV_EXCL_STOP
 		}
 	}
 
@@ -1179,8 +1199,10 @@ static void processFile(int input, int output, char const *name, off_t fileSize)
 	if (padValue != UNSPECIFIED) {
 		if (input == output) {
 			if (lseek(output, 0, SEEK_END) == static_cast<off_t>(-1)) {
+				// LCOV_EXCL_START
 				report("FATAL: Failed to seek to end of \"%s\": %s\n", name, strerror(errno));
 				return;
+				// LCOV_EXCL_STOP
 			}
 		}
 		memset(bank, padValue, sizeof(bank));
@@ -1194,40 +1216,73 @@ static void processFile(int input, int output, char const *name, off_t fileSize)
 			// The return value is either -1, or at most `thisLen`,
 			// so it's fine to cast to `size_t`
 			if (static_cast<size_t>(ret) != thisLen) {
+				// LCOV_EXCL_START
 				report("FATAL: Failed to write \"%s\"'s padding: %s\n", name, strerror(errno));
 				break;
+				// LCOV_EXCL_STOP
 			}
 			len -= thisLen;
 		}
 	}
 }
 
-static bool processFilename(char const *name) {
+static bool processFilename(char const *name, char const *outputName) {
 	nbErrors = 0;
 
-	if (!strcmp(name, "-")) {
+	bool inputStdin = !strcmp(name, "-");
+	if (inputStdin && !outputName) {
+		outputName = "-";
+	}
+
+	int output = -1;
+	bool openedOutput = false;
+	if (outputName) {
+		if (!strcmp(outputName, "-")) {
+			output = STDOUT_FILENO;
+			(void)setmode(STDOUT_FILENO, O_BINARY);
+		} else {
+			output = open(outputName, O_WRONLY | O_BINARY | O_CREAT, 0600);
+			if (output == -1) {
+				report(
+				    "FATAL: Failed to open \"%s\" for writing: %s\n", outputName, strerror(errno)
+				);
+				return true;
+			}
+			openedOutput = true;
+		}
+	}
+	Defer closeOutput{[&] {
+		if (openedOutput) {
+			close(output);
+		}
+	}};
+
+	if (inputStdin) {
 		name = "<stdin>";
 		(void)setmode(STDIN_FILENO, O_BINARY);
-		(void)setmode(STDOUT_FILENO, O_BINARY);
-		processFile(STDIN_FILENO, STDOUT_FILENO, name, 0);
+		processFile(STDIN_FILENO, output, name, 0, false);
 	} else {
 		// POSIX specifies that the results of O_RDWR on a FIFO are undefined.
 		// However, this is necessary to avoid a TOCTTOU, if the file was changed between
 		// `stat()` and `open(O_RDWR)`, which could trigger the UB anyway.
 		// Thus, we're going to hope that either the `open` fails, or it succeeds but IO
 		// operations may fail, all of which we handle.
-		if (int input = open(name, O_RDWR | O_BINARY); input == -1) {
+		if (int input = open(name, (outputName ? O_RDONLY : O_RDWR) | O_BINARY); input == -1) {
 			report("FATAL: Failed to open \"%s\" for reading+writing: %s\n", name, strerror(errno));
 		} else {
 			Defer closeInput{[&] { close(input); }};
 			struct stat stat;
 			if (fstat(input, &stat) == -1) {
+				// LCOV_EXCL_START
 				report("FATAL: Failed to stat \"%s\": %s\n", name, strerror(errno));
-			} else if (!S_ISREG(stat.st_mode)) { // TODO: Do we want to support other types?
+				// LCOV_EXCL_STOP
+			} else if (!S_ISREG(stat.st_mode)) { // We do not support FIFOs or symlinks
+				// LCOV_EXCL_START
 				report(
 				    "FATAL: \"%s\" is not a regular file, and thus cannot be modified in-place\n",
 				    name
 				);
+				// LCOV_EXCL_STOP
 			} else if (stat.st_size < 0x150) {
 				// This check is in theory redundant with the one in `processFile`, but it
 				// prevents passing a file size of 0, which usually indicates pipes
@@ -1237,7 +1292,10 @@ static bool processFilename(char const *name) {
 				    static_cast<intmax_t>(stat.st_size)
 				);
 			} else {
-				processFile(input, input, name, stat.st_size);
+				if (!outputName) {
+					output = input;
+				}
+				processFile(input, output, name, stat.st_size, true);
 			}
 		}
 	}
@@ -1281,6 +1339,7 @@ static void parseByte(uint16_t &output, char name) {
 int main(int argc, char *argv[]) {
 	nbErrors = 0;
 
+	char const *outputFilename = nullptr;
 	for (int ch; (ch = musl_getopt_long_only(argc, argv, optstring, longopts, nullptr)) != -1;) {
 		switch (ch) {
 			size_t len;
@@ -1322,8 +1381,10 @@ int main(int argc, char *argv[]) {
 			break;
 
 		case 'h':
+			// LCOV_EXCL_START
 			printUsage();
 			exit(0);
+			// LCOV_EXCL_STOP
 
 		case 'i':
 			gameID = musl_optarg;
@@ -1393,6 +1454,10 @@ int main(int argc, char *argv[]) {
 			overwriteRom = true;
 			break;
 
+		case 'o':
+			outputFilename = musl_optarg;
+			break;
+
 		case 'p':
 			parseByte(padValue, 'p');
 			break;
@@ -1419,16 +1484,20 @@ int main(int argc, char *argv[]) {
 		}
 
 		case 'V':
+			// LCOV_EXCL_START
 			printf("rgbfix %s\n", get_package_version_string());
 			exit(0);
+			// LCOV_EXCL_STOP
 
 		case 'v':
 			fixSpec = FIX_LOGO | FIX_HEADER_SUM | FIX_GLOBAL_SUM;
 			break;
 
 		default:
+			// LCOV_EXCL_START
 			printUsage();
 			exit(1);
+			// LCOV_EXCL_STOP
 		}
 	}
 
@@ -1462,7 +1531,7 @@ int main(int argc, char *argv[]) {
 				    "warning: RAM size 1 (2 KiB) was specified for MBC \"%s\"\n",
 				    mbcName(cartridgeType)
 				);
-			} // TODO: check possible values?
+			}
 		} else if (ramSize) {
 			fprintf(
 			    stderr,
@@ -1543,8 +1612,14 @@ int main(int argc, char *argv[]) {
 		exit(1);
 	}
 
+	if (outputFilename && argc != musl_optind + 1) {
+		fputs("FATAL: If `-o` is set then only a single input file may be specified\n", stderr);
+		printUsage();
+		exit(1);
+	}
+
 	do {
-		failed |= processFilename(*argv);
+		failed |= processFilename(*argv, outputFilename);
 	} while (*++argv);
 
 	return failed;
