@@ -23,29 +23,8 @@
 
 using namespace std::string_view_literals;
 
-constexpr uint8_t nibble(char c) {
-	if (c >= 'a') {
-		assume(c <= 'f');
-		return c - 'a' + 10;
-	} else if (c >= 'A') {
-		assume(c <= 'F');
-		return c - 'A' + 10;
-	} else {
-		assume(c >= '0' && c <= '9');
-		return c - '0';
-	}
-}
-
-constexpr uint8_t toHex(char c1, char c2) {
-	return nibble(c1) * 16 + nibble(c2);
-}
-
-constexpr uint8_t singleToHex(char c) {
-	return toHex(c, c);
-}
-
 template<typename Str> // Should be std::string or std::string_view
-static void skipWhitespace(Str const &str, typename Str::size_type &pos) {
+static void skipWhitespace(Str const &str, size_t &pos) {
 	pos = std::min(str.find_first_not_of(" \t"sv, pos), str.length());
 }
 
@@ -54,9 +33,8 @@ void parseInlinePalSpec(char const * const rawArg) {
 	// Palettes are separated by colons.
 
 	std::string_view arg(rawArg);
-	using size_type = decltype(arg)::size_type;
 
-	auto parseError = [&rawArg, &arg](size_type ofs, size_type len, char const *msg) {
+	auto parseError = [&rawArg, &arg](size_t ofs, size_t len, char const *msg) {
 		(void)arg; // With NDEBUG, `arg` is otherwise not used
 		assume(ofs <= arg.length());
 		assume(len <= arg.length());
@@ -80,17 +58,16 @@ void parseInlinePalSpec(char const * const rawArg) {
 	options.palSpec.clear();
 	options.palSpec.emplace_back(); // Value-initialized, not default-init'd, so we get zeros
 
-	size_type n = 0; // Index into the argument
-	// TODO: store max `nbColors` ever reached, and compare against palette size later
+	size_t n = 0;        // Index into the argument
 	size_t nbColors = 0; // Number of colors in the current palette
 	for (;;) {
 		++n; // Ignore the '#' (checked either by caller or previous loop iteration)
 
 		std::optional<Rgba> &color = options.palSpec.back()[nbColors];
-		// Check for #none first.
-		if (arg.compare(n, 4, "none"sv) == 0 || arg.compare(n, 4, "NONE"sv) == 0) {
+		// Check for "#none" first.
+		if (strncasecmp(&rawArg[n], "none", literal_strlen("none")) == 0) {
 			color = {};
-			n += 4;
+			n += literal_strlen("none");
 		} else {
 			auto pos = std::min(arg.find_first_not_of("0123456789ABCDEFabcdef"sv, n), arg.length());
 			switch (pos - n) {
@@ -194,7 +171,6 @@ static T readLE(U const *bytes) {
 [[gnu::warn_unused_result]]
 static bool readLine(std::filebuf &file, std::string &buffer) {
 	assume(buffer.empty());
-	// TODO: maybe this can be optimized to bulk reads?
 	for (;;) {
 		auto c = file.sbumpc();
 		if (c == std::filebuf::traits_type::eof()) {
@@ -222,7 +198,7 @@ static bool readLine(std::filebuf &file, std::string &buffer) {
 
 // Parses the initial part of a string_view, advancing the "read index" as it does
 template<typename U> // Should be uint*_t
-static std::optional<U> parseDec(std::string const &str, std::string::size_type &n) {
+static std::optional<U> parseDec(std::string const &str, size_t &n) {
 	uintmax_t value = 0;
 	auto result = std::from_chars(str.data() + n, str.data() + str.size(), value);
 	if (static_cast<bool>(result.ec)) {
@@ -232,8 +208,7 @@ static std::optional<U> parseDec(std::string const &str, std::string::size_type
 	return std::optional<U>{value};
 }
 
-static std::optional<Rgba>
-    parseColor(std::string const &str, std::string::size_type &n, uint16_t i) {
+static std::optional<Rgba> parseColor(std::string const &str, size_t &n, uint16_t i) {
 	std::optional<uint8_t> r = parseDec<uint8_t>(str, n);
 	if (!r) {
 		error("Failed to parse color #%d (\"%s\"): invalid red component", i + 1, str.c_str());
@@ -281,7 +256,7 @@ static void parsePSPFile(std::filebuf &file) {
 
 	line.clear();
 	requireLine("PSP", file, line);
-	std::string::size_type n = 0;
+	size_t n = 0;
 	std::optional<uint16_t> nbColors = parseDec<uint16_t>(line, n);
 	if (!nbColors || n != line.length()) {
 		error("Invalid \"number of colors\" line in PSP file (%s)", line.c_str());
@@ -347,7 +322,7 @@ static void parseGPLFile(std::filebuf &file) {
 			continue;
 		}
 
-		std::string::size_type n = 0;
+		size_t n = 0;
 		skipWhitespace(line, n);
 		// Skip empty lines, or lines that contain just a comment.
 		if (line.length() == n || line[n] == '#') {
@@ -438,7 +413,6 @@ static void parseACTFile(std::filebuf &file) {
 	uint16_t nbColors = 256;
 	if (len == 772) {
 		nbColors = readBE<uint16_t>(&buf[768]);
-		// TODO: apparently there is a "transparent color index"? What?
 		if (nbColors > 256 || nbColors == 0) {
 			error("Invalid number of colors in ACT file (%" PRIu16 ")", nbColors);
 			return;
@@ -549,9 +523,6 @@ static void parseACOFile(std::filebuf &file) {
 			return;
 		}
 	}
-
-	// TODO: maybe scan the v2 data instead (if present)
-	// `codecvt` can be used to convert from UTF-16 to UTF-8
 }
 
 static void parseGBCFile(std::filebuf &file) {
@@ -603,10 +574,9 @@ void parseExternalPalSpec(char const *arg) {
 	    std::tuple{"GBC", &parseGBCFile, std::ios::binary},
 	};
 
-	auto iter =
-	    std::find_if(RANGE(parsers), [&arg, &ptr](decltype(parsers)::value_type const &parser) {
-		    return strncasecmp(arg, std::get<0>(parser), ptr - arg) == 0;
-	    });
+	auto iter = std::find_if(RANGE(parsers), [&arg, &ptr](auto const &parser) {
+		return strncasecmp(arg, std::get<0>(parser), ptr - arg) == 0;
+	});
 	if (iter == parsers.end()) {
 		error(
 		    "Unknown external palette format \"%.*s\"",
