@@ -1,13 +1,10 @@
-/* SPDX-License-Identifier: MIT */
+// SPDX-License-Identifier: MIT
 
 #include "util.hpp"
 
 #include <ctype.h>
 #include <stdint.h>
 #include <stdio.h>
-#include <vector>
-
-#include "extern/utf8decoder.hpp"
 
 char const *printChar(int c) {
 	// "'A'" + '\0': 4 bytes
@@ -15,8 +12,9 @@ char const *printChar(int c) {
 	// "0xFF" + '\0': 5 bytes
 	static char buf[5];
 
-	if (c == EOF)
+	if (c == EOF) {
 		return "EOF";
+	}
 
 	if (isprint(c)) {
 		buf[0] = '\'';
@@ -43,7 +41,7 @@ char const *printChar(int c) {
 	default: // Print as hex
 		buf[0] = '0';
 		buf[1] = 'x';
-		snprintf(&buf[2], 3, "%02hhX", (uint8_t)c); // includes the '\0'
+		snprintf(&buf[2], 3, "%02hhX", static_cast<uint8_t>(c)); // includes the '\0'
 		return buf;
 	}
 	buf[0] = '\'';
@@ -52,21 +50,3 @@ char const *printChar(int c) {
 	buf[4] = '\0';
 	return buf;
 }
-
-size_t readUTF8Char(std::vector<uint8_t> *dest, char const *src) {
-	uint32_t state = 0;
-	uint32_t codep;
-	size_t i = 0;
-
-	for (;;) {
-		if (decode(&state, &codep, src[i]) == 1)
-			return 0;
-
-		if (dest)
-			dest->push_back(src[i]);
-		i++;
-
-		if (state == 0)
-			return i;
-	}
-}
